Package: shinyAce
Type: Package
Title: Ace Editor Bindings for Shiny
Version: 0.2.1
Date: 2016-03-13
Authors@R: c(
  person(family="Trestle Technology, LLC", role="aut", email="cran@trestletechnology.net"),
  person("Jeff", "Allen", role="cre", email="cran@trestletechnology.net"),
  person(family="Institut de Radioprotection et de Surete Nucleaire", role=c("cph"), email = "yann.richet@irsn.fr"),
  person(family="Ajax.org B.V.", role=c("ctb", "cph"), comment="Ace"))
Description: Ace editor bindings to enable a rich text editing environment
    within Shiny.
License: MIT + file LICENSE
Depends: R (>= 2.15.0)
Imports: shiny (>= 0.7.0)
Suggests: testthat, dplyr (>= 0.3.0)
BugReports: https://github.com/trestletech/shinyAce/issues
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2016-03-14 17:13:18 UTC; jeff
Author: Trestle Technology, LLC [aut],
  Jeff Allen [cre],
  Institut de Radioprotection et de Surete Nucleaire [cph],
  Ajax.org B.V. [ctb, cph] (Ace)
Maintainer: Jeff Allen <cran@trestletechnology.net>
Repository: CRAN
Date/Publication: 2016-03-14 23:53:35
Built: R 3.3.2; ; 2017-09-24 18:55:43 UTC; windows
