# Generated by roxygen2: do not edit by hand

export(aceAutocomplete)
export(aceEditor)
export(getAceModes)
export(getAceThemes)
export(updateAceEditor)
import(shiny)
importFrom(utils,compareVersion)
importFrom(utils,packageVersion)
